from . import access
import agilicus
import jwt

CONTEXT = None
API_DEFAULT = "https://api.agilicus.com"
CACERT_DEFAULT = True
CLIENT_ID_DEFAULT = "admin-portal"
ISSUER_DEFAULT = "https://auth.cloud.agilicus.dev"
HEADER_DEFAULT = True
ORG_ID_DEFAULT = ""


class ApiHelper:
    def __init__(self, ctx, token):
        self.configuration = agilicus.Configuration()
        self.configuration.host = get_value(ctx, "API")
        cacert = get_value(ctx, "CACERT")
        if cacert is not True:
            self.configuration.ssl_ca_cert = cacert
        if token:
            self.configuration.access_token = token
        else:
            self.configuration.access_token = get_token(ctx)
        self.org_api = agilicus.OrganisationsApi(agilicus.ApiClient(self.configuration))
        self.application_api = agilicus.ApplicationsApi(
            agilicus.ApiClient(self.configuration)
        )
        self.app_services_api = agilicus.ApplicationServicesApi(
            agilicus.ApiClient(self.configuration)
        )
        self.user_api = agilicus.UsersApi(agilicus.ApiClient(self.configuration))
        self.logs_api = agilicus.DiagnosticsApi(agilicus.ApiClient(self.configuration))
        self.metrics_api = agilicus.MetricsApi(agilicus.ApiClient(self.configuration))
        self.issuers_api = agilicus.IssuersApi(agilicus.ApiClient(self.configuration))
        self.tokens_api = agilicus.TokensApi(agilicus.ApiClient(self.configuration))
        self.audits_api = agilicus.AuditsApi(agilicus.ApiClient(self.configuration))
        self.catalogues_api = agilicus.CataloguesApi(
            agilicus.ApiClient(self.configuration)
        )
        self.permissions_api = agilicus.PermissionsApi(
            agilicus.ApiClient(self.configuration)
        )
        self.challenges_api = agilicus.ChallengesApi(
            agilicus.ApiClient(self.configuration)
        )


def setup(ctx):
    ctx.ensure_object(dict)
    ctx.obj.setdefault("API", API_DEFAULT)
    ctx.obj.setdefault("CACERT", CACERT_DEFAULT)
    ctx.obj.setdefault("CLIENT_ID", CLIENT_ID_DEFAULT)
    ctx.obj.setdefault("ISSUER", ISSUER_DEFAULT)
    ctx.obj.setdefault("ISSUER", ISSUER_DEFAULT)
    ctx.obj.setdefault("ORG_ID", ORG_ID_DEFAULT)
    ctx.obj.setdefault("HEADER", HEADER_DEFAULT)
    save(ctx)


def get_value(ctx, value):
    if value in ctx.obj:
        return ctx.obj[value]
    if value in CONTEXT.obj:
        return CONTEXT.obj[value]


def get_token(ctx, refresh=None):
    token = get_value(ctx, "TOKEN")
    if not token:
        access_token = access.get_access_token(ctx, refresh=refresh)
        token = access_token.get()
    return token


def get_apiclient_from_ctx(ctx, refresh=None):
    return get_apiclient(ctx, get_token(ctx, refresh))


def header(ctx):
    return get_value(ctx, "HEADER")


def save(ctx):
    global CONTEXT
    CONTEXT = ctx


def get_apiclient(ctx, user_token=None):
    api = ApiHelper(ctx, user_token)
    return api


def get_api(ctx):
    return get_value(ctx, "API")


def get_cacert(ctx):
    return get_value(ctx, "CACERT")


def get_client_id(ctx):
    return get_value(ctx, "CLIENT_ID")


def get_auth_local_webserver(ctx):
    return get_value(ctx, "AUTH_LOCAL_WEBSERVER")


def get_client_secret(ctx):
    return get_value(ctx, "CLIENT_SECRET")


def get_issuer(ctx):
    return get_value(ctx, "ISSUER")


def get_org(ctx):
    return get_value(ctx, "ORGANISATION")


def get_scopes(ctx):
    return get_value(ctx, "SCOPES")


def get_org_id(ctx, user_token=None):
    # first check to see if an org is chosen
    # via context/env
    if get_value(ctx, "ORG_ID") and get_value(ctx, "ORG_ID"):
        return get_value(ctx, "ORG_ID")

    # Next check to see if a token was passed in via
    # context/env
    if get_value(ctx, "TOKEN"):
        token = jwt.decode(get_value(ctx, "TOKEN"), verify=False)
        if "org_id" in token:
            return token["org_id"]

    # finally check to see if the users token
    # has an org
    if user_token:
        token = jwt.decode(user_token, verify=False)
        if "org" in token:
            return token["org"]



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.07.09
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_role_to_rule_entries import ListRoleToRuleEntries  # noqa: E501
from agilicus_api.rest import ApiException

class TestListRoleToRuleEntries(unittest.TestCase):
    """ListRoleToRuleEntries unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListRoleToRuleEntries
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_role_to_rule_entries.ListRoleToRuleEntries()  # noqa: E501
        if include_optional :
            return ListRoleToRuleEntries(
                limit = 56, 
                role_to_rule_entries = [
                    agilicus_api.models.role_to_rule_entry.RoleToRuleEntry(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.role_to_rule_entry_spec.RoleToRuleEntrySpec(
                            role_id = '123', 
                            rule_id = '123', 
                            app_id = '123', 
                            org_id = '123', 
                            included = True, ), )
                    ]
            )
        else :
            return ListRoleToRuleEntries(
                limit = 56,
        )

    def testListRoleToRuleEntries(self):
        """Test ListRoleToRuleEntries"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.07.09
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class RuleSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_id': 'str',
        'comments': 'str',
        'condition': 'HttpRule',
        'org_id': 'str',
        'scope': 'RuleScope'
    }

    attribute_map = {
        'app_id': 'app_id',
        'comments': 'comments',
        'condition': 'condition',
        'org_id': 'org_id',
        'scope': 'scope'
    }

    def __init__(self, app_id=None, comments=None, condition=None, org_id=None, scope=None, local_vars_configuration=None):  # noqa: E501
        """RuleSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_id = None
        self._comments = None
        self._condition = None
        self._org_id = None
        self._scope = None
        self.discriminator = None

        if app_id is not None:
            self.app_id = app_id
        if comments is not None:
            self.comments = comments
        if condition is not None:
            self.condition = condition
        if org_id is not None:
            self.org_id = org_id
        if scope is not None:
            self.scope = scope

    @property
    def app_id(self):
        """Gets the app_id of this RuleSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The app_id of this RuleSpec.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this RuleSpec.

        Unique identifier  # noqa: E501

        :param app_id: The app_id of this RuleSpec.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def comments(self):
        """Gets the comments of this RuleSpec.  # noqa: E501

        A description of the rule. The comments have no functional effect, but can help to clarify the purpose of a rule when the name is not sufficient.   # noqa: E501

        :return: The comments of this RuleSpec.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this RuleSpec.

        A description of the rule. The comments have no functional effect, but can help to clarify the purpose of a rule when the name is not sufficient.   # noqa: E501

        :param comments: The comments of this RuleSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                comments is not None and len(comments) > 2047):
            raise ValueError("Invalid value for `comments`, length must be less than or equal to `2047`")  # noqa: E501

        self._comments = comments

    @property
    def condition(self):
        """Gets the condition of this RuleSpec.  # noqa: E501


        :return: The condition of this RuleSpec.  # noqa: E501
        :rtype: HttpRule
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this RuleSpec.


        :param condition: The condition of this RuleSpec.  # noqa: E501
        :type: HttpRule
        """

        self._condition = condition

    @property
    def org_id(self):
        """Gets the org_id of this RuleSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this RuleSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this RuleSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this RuleSpec.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def scope(self):
        """Gets the scope of this RuleSpec.  # noqa: E501


        :return: The scope of this RuleSpec.  # noqa: E501
        :rtype: RuleScope
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this RuleSpec.


        :param scope: The scope of this RuleSpec.  # noqa: E501
        :type: RuleScope
        """

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RuleSpec):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from agilicus_api.api.application_services_api import ApplicationServicesApi
from agilicus_api.api.applications_api import ApplicationsApi
from agilicus_api.api.audits_api import AuditsApi
from agilicus_api.api.catalogues_api import CataloguesApi
from agilicus_api.api.challenges_api import ChallengesApi
from agilicus_api.api.diagnostics_api import DiagnosticsApi
from agilicus_api.api.files_api import FilesApi
from agilicus_api.api.groups_api import GroupsApi
from agilicus_api.api.issuers_api import IssuersApi
from agilicus_api.api.messages_api import MessagesApi
from agilicus_api.api.metrics_api import MetricsApi
from agilicus_api.api.organisations_api import OrganisationsApi
from agilicus_api.api.permissions_api import PermissionsApi
from agilicus_api.api.services_api import ServicesApi
from agilicus_api.api.tokens_api import TokensApi
from agilicus_api.api.users_api import UsersApi
from agilicus_api.api.whoami_api import WhoamiApi
